===============================
CLARITE
===============================

.. image:: https://img.shields.io/travis/HallLab/clarite-python.svg
        :target: https://travis-ci.org/HallLab/clarite-python

.. image:: https://img.shields.io/pypi/v/clarite.svg
        :target: https://pypi.python.org/pypi/clarite


CLeaning to Anlaysis: Reproducibility-based Interface for Traits and Exposures

* Free software: 3-clause BSD license
* Documentation: https://HallLab.github.io/clarite-python.
